@@ -6,6 +6,7 @@ require 'inline'
 require 'tempfile'
 require 'tmpdir'
 require 'test/unit'
+require 'fileutils' unless defined?(::FileUtils)
 
 File.umask(0)
 
@@ -26,6 +27,7 @@ class InlineTestCase < Test::Unit::TestCase
     @rootdir = File.join(Dir.tmpdir, "test_inline.#{$$}")
     Dir.mkdir @rootdir, 0700 unless test ?d, @rootdir
     ENV['INLINEDIR'] = @rootdir
+    Dir.mkdir Inline.directory, 0700
   end
 
   def teardown
@@ -56,7 +58,7 @@ class TestDir < InlineTestCase
         Dir.assert_secure path
       end
     else
-      assert_raises(perms.nil? ? Errno::ENOENT : SecurityError) do
+      assert_raises(SecurityError) do
         Dir.assert_secure path
       end
     end
@@ -70,7 +72,7 @@ class TestDir < InlineTestCase
     util_assert_secure 0770, false
     util_assert_secure 0777, false
     # missing
-    util_assert_secure nil, false
+    util_assert_secure nil, true
   end
 end unless Inline::WINDOZE
 
@@ -636,11 +638,14 @@ class TestModule < InlineTestCase
     tempfile.write($test_module_code2)
     tempfile.flush
     tempfile.rewind
-    `cp #{tempfile.path} #{tempfile.path}.rb`
+    
+    FileUtils.cp tempfile.path, "#{tempfile.path}.rb"
+    
     require "#{tempfile.path}.rb"
     assert_equal(12, fb.twelve_instance)
     assert_equal(12, Foo::Bar.twelve_class)
-    `rm "#{tempfile.path}.rb"`
+    
+    FileUtils.rm "#{tempfile.path}.rb"
   end
 
   def test_argument_check_good
